==> l7-source-2.11.7.tgz: package/lib/utils/tile/getCustomData.js <==
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/utils/tile/getCustomData.ts
var getCustomData_exports = {};
__export(getCustomData_exports, {
  getCustomData: () => getCustomData
});
module.exports = __toCommonJS(getCustomData_exports);
var import_bands = require("../bandOperation/bands");
var getCustomData = async (tile, getCustomData2, rasterFormat, operation) => {
  return new Promise((resolve, reject) => {
    getCustomData2({
      x: tile.x,
      y: tile.y,
      z: tile.z
    }, (err, data) => {
      if (err || data.length === 0) {
        reject(err);
        return;
      }
      if (data) {
        (0, import_bands.processRasterData)([{ data, bands: [0] }], rasterFormat, operation, (err2, img) => {
          if (err2) {
            reject(err2);
          } else if (img) {
            resolve(img);
          }
        });
      }
    });
  });
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  getCustomData
});

==> l7-source-2.15.1.tgz: package/lib/utils/tile/getCustomData.js <==
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/utils/tile/getCustomData.ts
var getCustomData_exports = {};
__export(getCustomData_exports, {
  getCustomData: () => getCustomData,
  getCustomImageData: () => getCustomImageData
});
module.exports = __toCommonJS(getCustomData_exports);
var import_l7_utils = require("@antv/l7-utils");
var import_bands = require("../bandOperation/bands");
var getCustomData = async (tile, getCustomDataFunc, rasterFormat, operation) => {
  return new Promise((resolve, reject) => {
    getCustomDataFunc({
      x: tile.x,
      y: tile.y,
      z: tile.z
    }, (err, data) => {
      if (err || data.length === 0) {
        reject(err);
        return;
      }
      if (data) {
        (0, import_bands.processRasterData)([{ data, bands: [0] }], rasterFormat, operation, (error, img) => {
          if (error) {
            reject(error);
          } else if (img) {
            resolve(img);
          }
        });
      }
    });
  });
};
var getCustomImageData = async (tile, getCustomDataFunc) => {
  return new Promise((resolve, reject) => {
    getCustomDataFunc({
      x: tile.x,
      y: tile.y,
      z: tile.z
    }, (err, data) => {
      if (err || !data) {
        reject(err);
        return;
      }
      if (data instanceof ArrayBuffer) {
        (0, import_l7_utils.formatImage)(data, (error, image) => {
          if (error) {
            reject(error);
          }
          resolve(image);
        });
      } else if (data instanceof HTMLImageElement) {
        resolve(data);
      } else {
        reject(err);
      }
    });
  });
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  getCustomData,
  getCustomImageData
});
